@@ -28,6 +28,12 @@ G_DECLARE_DERIVABLE_TYPE (HdyPreferencesRow, hdy_preferences_row, HDY, PREFERENC
 struct _HdyPreferencesRowClass
 {
   GtkListBoxRowClass parent_class;
+
+  /*< private >*/
+  /* FIXME We can't use the padding because of an error in HdyActionRowClass
+   * that we can't fix without breaking the ABI.
+   */
+  gpointer padding[4];
 };
 
 HDY_AVAILABLE_IN_ALL
